@@ -144,14 +144,14 @@ def push_image(config, image_name, image_tag):
     _logger.info('Image pushed correctly')
 
 
-def notify_orchest(config, customer, is_latest=False):
+def notify_orchest(config, is_latest=False):
     img_repo = config.get('docker_image_repo') or config['image_repo']
     image_name = '{image}:{tag}'.format(image=img_repo, tag=config['image_tag'])
     res = requests.post(
         config['orchest_registry'], data=json.dumps({
             'image_name': image_name, 'is_latest': is_latest, 'branch_name': config['ci_commit_ref_name'],
             'job_id': config['ci_job_id'], 'project_id': config['ci_project_id'],
-            'commit': config['ci_commit_sha'][:7], 'customer_id': customer}),
+            'commit': config['ci_commit_sha'][:7], 'customer_id': config['customer_img']}),
         headers={'Content-Type': 'application/json', 'Orchest-Token': config['orchest_token']})
     if res.status_code != 200:
         _logger.error('Failed to notify orchest about the new image: %s', res.text)
